@@ -1,25 +1,26 @@
 package Sys::Info;
 use strict;
+use warnings;
 use vars qw( $VERSION @EXPORT_OK );
-use Carp qw( croak );
+use Carp qw( croak    );
 use Sys::Info::Constants qw( OSID );
+use base qw( Sys::Info::Base );
 
-$VERSION = '0.72';
+$VERSION = '0.73';
 @EXPORT_OK = qw( OSID );
 
 __PACKAGE__->_mk_object( $_ ) for qw( OS Device );
 
 sub import {
-    my $class  = shift;
+    my($class, @names) = @_;
     my $caller = caller;
-    my @names  = @_;
     my %cache  = map { $_ => 1 } @EXPORT_OK;
     no strict qw( refs );
     foreach my $name ( @names ) {
         croak "Bogus import: $name"                 if not $class->can($name);
         croak "Caller already has the $name method" if     $caller->can($name);
         croak "Access denied for $name"             if not exists $cache{$name};
-        *{ $caller . '::' . $name } = *{ $class . '::' . $name };
+        *{ $caller . q{::} . $name } = *{ $class . q{::} . $name };
     }
     return;
 }
@@ -31,7 +32,7 @@ sub new {
     return $self;
 }
 
-sub perl { defined $^V ? sprintf( '%vd', $^V ) : _legacy_perl( $] ) }
+sub perl { return defined $^V ? sprintf( '%vd', $^V ) : _legacy_perl( $] ) }
 
 sub perl_build {
     return 0 if OSID ne 'Windows';
@@ -40,7 +41,7 @@ sub perl_build {
     return Win32::BuildNumber();
 }
 
-sub perl_long { join '.', perl(), perl_build() }
+sub perl_long { return join q{.}, perl(), perl_build() }
 
 sub httpd {
     my $self   = shift;
@@ -52,17 +53,17 @@ sub httpd {
 
     if ( $server   =~ m{\A (Apache)/(.+?) \z}xmsi ) {
         my $apache = $1;
-        my @data   = split /\s+/, $2;
+        my @data   = split /\s+/xms, $2;
         my $v      = shift @data;
         my @mods;
         my($mn, $mv);
         foreach my $e (@data) {
             next if $e =~ m{ \A \( .+? \) \z}xms;
-            ($mn,$mv) = split /\//, $e;
-            $mn =~ s,-(.+?)$,,;
-            push @mods, $mn.'('.$mv.')';
+            ($mn,$mv) = split m{/}xms, $e;
+            $mn =~ s{ \-(.+?) \z }{}xms;
+            push @mods, $mn .'(' . $mv . ')';
         }
-        return "$apache $v. Modules: ".join(" ", @mods);
+        return "$apache $v. Modules: " . join q{ }, @mods;
     }
 
    return $server;
@@ -72,11 +73,12 @@ sub httpd {
 
 sub _mk_object {
     my $self  = shift;
-    my $name  = shift || croak "_mk_object() needs a name";
-    my $class = 'Sys::Info::' . $name;
-    (my $file = $class) =~ s{::}{/}xmsg;
+    my $name  = shift || croak '_mk_object() needs a name';
     no strict qw(refs);
-    *{ lc $name } = sub { shift; require "$file.pm"; return "$class"->new(@_) };
+    *{ lc $name } = sub {
+        shift->load_module( 'Sys::Info::' . $name )->new( @_ );
+    };
+    return;
 }
 
 sub _legacy_perl { # function
@@ -84,7 +86,7 @@ sub _legacy_perl { # function
     my($rev, $patch_sub) = split m{[.]}xms, $v;
     $patch_sub =~ s{[0_]}{}xmsg;
     my @v = split m{}xms, $patch_sub;
-    return sprintf( '%d.%d.%d', $rev, $v[0], $v[1] || '0' );
+    return sprintf '%d.%d.%d', $rev, $v[0], $v[1] || '0';
 }
 
 1;
@@ -110,8 +112,8 @@ Sys::Info - Fetch information from the host system
 
 =head1 DESCRIPTION
 
-This document describes version C<0.72> of C<Sys::Info>
-released on C<3 May 2009>.
+This document describes version C<0.73> of C<Sys::Info>
+released on C<14 January 2010>.
 
 Extracts and collects information from the host system.
 
@@ -150,10 +152,6 @@ This method is just a combination of C<perl> & C<perl_build>.
 If the code is used under a HTTP server and this server is recognised,
 returns the name of this server. Returns C<undef> otherwise.
 
-=head2 cpu
-
-Deprecated. Use the device() method instead.
-
 =head1 CONSTANTS
 
 =head2 OSID
@@ -191,16 +189,16 @@ L<Win32::TieRegistry>
 
 =head1 AUTHOR
 
-Burak Grsoy, E<lt>burakE<64>cpan.orgE<gt>
+Burak Gursoy <burak@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2006-2009 Burak Grsoy. All rights reserved.
+Copyright 2006 - 2010 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.10.0 or, 
+it under the same terms as Perl itself, either Perl version 5.10.1 or, 
 at your option, any later version of Perl 5 you may have available.
 
 =cut
